@@ -18,7 +18,7 @@ class AuthenticateModel:
 
     @declared_attr
     def user_id(cls):
-        return Column(Integer, ForeignKey('user.id'), nullable=True)
+        return Column(Integer, ForeignKey('users.id'), nullable=True)
 
     def __repr__(self):
         return f'<AuthToken: {self.user_id}'
